@@ -3,51 +3,63 @@ knitr::opts_chunk$set(echo = TRUE, message = FALSE, warning = FALSE)
 
 ## ---- message = FALSE, warning=FALSE------------------------------------------
 library(CAST)
-library(virtualspecies)
 library(caret)
-library(raster)
-library(sp)
+library(terra)
+#library(sp)
 library(sf)
 library(viridis)
 library(latticeExtra)
 library(gridExtra)
 
+## ----message = FALSE, warning=FALSE-------------------------------------------
+
+generate_random_response <- function(raster, predictornames =
+names(raster), seed = sample(seq(1000), 1)){
+  operands_1 = c("+", "-", "*", "/")
+  operands_2 = c("^1","^2")
+  
+  expression <- paste(as.character(predictornames, sep=""))
+  # assign random power to predictors
+  set.seed(seed)
+  expression <- paste(expression,
+                      sample(operands_2, length(predictornames),
+replace = TRUE),
+                      sep = "")
+  
+  # assign random math function between predictors (expect after the last one)
+  set.seed(seed)
+  expression[-length(expression)] <- paste(expression[-
+length(expression)],
+                                           sample(operands_1,
+length(predictornames)-1, replace = TRUE),
+                                           sep = " ")
+  print(paste0(expression, collapse = " "))
+  # collapse
+  e = paste0("raster$", expression, collapse = " ")
+  
+  response = eval(parse(text = e))
+  names(response) <- "response"
+  return(response)
+  
+}
+
 ## ---- message = FALSE, warning=FALSE------------------------------------------
-predictors <- stack(system.file("extdata","bioclim.grd",package="CAST"))
-response <- generateSpFromPCA(predictors,
-                              means = c(3,1),sds = c(2,2), plot=F)$suitab.raster
+predictors <- rast(system.file("extdata","bioclim.grd",package="CAST"))
+response <- generate_random_response (predictors, seed = 10)
 
 
 mask <- predictors[[1]]
 values(mask)[!is.na(values(mask))] <- 1
-mask <- rasterToPolygons(mask)
+mask <- st_as_sf(as.polygons(mask))
 
-# Generate Clustered Training Samples
-csample <- function(x,n,nclusters,maxdist,seed){
-  set.seed(seed)
-  cpoints <- sp::spsample(x, n = nclusters, type="random")
-  result <- cpoints
-  result$clstrID <- 1:length(cpoints)
-  for (i in 1:length(cpoints)){
-    ext <- rgeos::gBuffer(cpoints[i,], width = maxdist)
-    newsamples <- sp::spsample(ext, n = (n-nclusters)/nclusters, 
-                               type="random")
-    newsamples$clstrID <- rep(i,length(newsamples))
-    result <- rbind(result,newsamples)
-    
-  }
-  result$ID <- 1:nrow(result)
-  return(result)
-}
+set.seed(15)
+samplepoints <- clustered_sample(mask,75,15,radius=25000)
 
 
-samplepoints <- csample(mask,75,15,maxdist=0.20,seed=15)
-
-
-trainDat <- extract(predictors,samplepoints,df=TRUE)
-trainDat$response <- extract (response,samplepoints)
-trainDat <- merge(trainDat,samplepoints,by.x="ID",by.y="ID")
-trainDat <- trainDat[complete.cases(trainDat),]
+trainDat <- extract(predictors,samplepoints,na.rm=TRUE)
+trainDat$response <- extract(response,samplepoints,na.rm=FALSE)$response
+trainDat <- data.frame(trainDat,samplepoints)
+trainDat <- na.omit(trainDat)
 
 ## ----message = FALSE, warning=FALSE-------------------------------------------
 set.seed(10)
@@ -56,7 +68,7 @@ model_random <- train(trainDat[,names(predictors)],
                method="rf",
                importance=TRUE,
                trControl = trainControl(method="cv"))
-prediction_random <- raster::predict(predictors,model_random)
+prediction_random <- predict(predictors,model_random,na.rm=TRUE)
 
 ## -----------------------------------------------------------------------------
 model_random_trainDI = trainDI(model_random)
@@ -65,22 +77,23 @@ print(model_random_trainDI)
 ## ---- eval = FALSE------------------------------------------------------------
 #  saveRDS(model_random_trainDI, "path/to/file")
 
-## -----------------------------------------------------------------------------
+## ----  fig.show="hold", out.width="30%"---------------------------------------
 r1 = crop(predictors, c(0,7,42.33333,54.83333))
 r2 = crop(predictors, c(7,14,42.33333,54.83333))
 r3 = crop(predictors, c(14,21,42.33333,54.83333))
 
-grid.arrange(spplot(r1[[1]], main = "Tile 1"),
-             spplot(r2[[1]], main = "Tile 2"),
-             spplot(r3[[1]], main = "Tile 3"), ncol = 3)
 
-## -----------------------------------------------------------------------------
+plot(r1[[1]],main = "Tile 1")
+plot(r2[[1]],main = "Tile 2")
+plot(r3[[1]],main = "Tile 3")
+
+## ----  fig.show="hold", out.width="30%"---------------------------------------
 
 aoa_r1 = aoa(newdata = r1, trainDI = model_random_trainDI)
 
-grid.arrange(spplot(r1[[1]], main = "Tile 1: Predictors"),
-             spplot(aoa_r1$DI, main = "Tile 1: DI"),
-             spplot(aoa_r1$AOA, main = "Tile 1: AOA"), ncol = 3)
+plot(r1[[1]], main = "Tile 1: Predictors")
+plot(aoa_r1$DI, main = "Tile 1: DI")
+plot(aoa_r1$AOA, main = "Tile 1: AOA")
 
 
 ## ---- eval = FALSE------------------------------------------------------------
@@ -98,10 +111,10 @@ tiles_aoa = lapply(list(r1, r2, r3), function(tile){
   aoa(newdata = tile, trainDI = model_random_trainDI)
 })
 
-## -----------------------------------------------------------------------------
-grid.arrange(spplot(tiles_aoa[[1]]$AOA, main = "Tile 1"),
-             spplot(tiles_aoa[[2]]$AOA, main = "Tile 2"),
-             spplot(tiles_aoa[[3]]$AOA, main = "Tile 3"), ncol = 3)
+## ----  fig.show="hold", out.width="30%"---------------------------------------
+plot(tiles_aoa[[1]]$AOA, main = "Tile 1")
+plot(tiles_aoa[[2]]$AOA, main = "Tile 2")
+plot(tiles_aoa[[3]]$AOA, main = "Tile 3")
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  # Simple Example Code for raster tiles on the hard drive
@@ -109,7 +122,7 @@ grid.arrange(spplot(tiles_aoa[[1]]$AOA, main = "Tile 1"),
 #  tiles = list.files("path/to/tiles", full.names = TRUE)
 #  
 #  tiles_aoa = mclapply(tiles, function(tile){
-#    current = raster::stack(tile)
+#    current = terra::rast(tile)
 #    aoa(newdata = current, trainDI = model_random_trainDI)
 #  
 #  }, mc.cores = 3)
